==> websvn_2.3.1.orig.tar.gz: websvn-2.3.1/languages/languages.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004-2006 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// languages.php
//
// declares all available languages

// language tag => array(base filename, name in English, name in native tongue)
$languages = array(
  'ca'    => array('catalan', 'Catalan', 'Catal&agrave;-Valenci&agrave;'),
  'zh-CN' => array('chinese-simplified', 'Chinese (Simplified)', '&#20013;&#25991;'),
  'zh-TW' => array('chinese-traditional', 'Chinese (Traditional)', '&#20013;&#25991;'),
  'cs'    => array('czech', 'Czech', '&#268;esky'),
  'da'    => array('danish', 'Danish', 'Dansk'),
  'nl'    => array('dutch', 'Dutch', 'Nederlands'),
  'en'    => array('english', 'English', 'English'),
  'fi'    => array('finnish', 'Finnish', 'Suomi'),
  'fr'    => array('french', 'French', 'Fran&ccedil;ais'),
  'de'    => array('german', 'German', 'Deutsch'),
  'he-IL' => array('hebrew', 'Hebrew', '&#1506;&#1489;&#1512;&#1497;&#1514;'),
  'hin'   => array('hindi', 'Hindi', '&#2361;&#2367;&#2306;&#2342;&#2368;'),
  'hu'    => array('hungarian', 'Hungarian', 'Magyar'),
  'id'    => array('indonesian', 'Indonesian', 'Bahasa Indonesia'),
  'it'    => array('italian', 'Italian', 'Italiano'),
  'ja'    => array('japanese', 'Japanese', '&#26085;&#26412;&#35486;'),
  'ko'    => array('korean', 'Korean', '&#54620;&#44397;&#50612;'),
  'mr'    => array('marathi', 'Marathi', '&#2350;&#2352;&#2366;&#2336;&#2368;'),
  'no'    => array('norwegian', 'Norwegian', 'Norsk'),
  'pl'    => array('polish', 'Polish', 'Polski'),
  'pt'    => array('portuguese', 'Portuguese', 'Portugu&ecirc;s'),
  'pt-BR' => array('portuguese-br', 'Portuguese (Brazil)', 'Portugu&ecirc;s'),
  'ru'    => array('russian', 'Russian', '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;'),
  'sk'    => array('slovak', 'Slovak', 'Sloven&#269;ina'),
  'sl'    => array('slovenian', 'Slovenian', 'Sloven&#353;&#269;ina'),
  'es'    => array('spanish', 'Spanish', 'Espa&ntilde;ol'),
  'sv'    => array('swedish', 'Swedish', 'Svenska'),
  'tr'    => array('turkish', 'Turkish', 'T&uuml;rk&ccedil;e'),
  'uz'    => array('uzbek', 'Uzbek', 'O&euml;zbekcha'),
);

==> websvn_2.3.2.orig.tar.gz: websvn-2.3.2/languages/languages.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004-2006 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// languages.php
//
// declares all available languages

// language tag => array(base filename, name in English, name in native tongue)
$languages = array(
  'ca'    => array('catalan', 'Catalan', 'Catal&agrave;-Valenci&agrave;'),
  'zh-CN' => array('chinese-simplified', 'Chinese (Simplified)', '&#20013;&#25991;'),
  'zh-TW' => array('chinese-traditional', 'Chinese (Traditional)', '&#20013;&#25991;'),
  'cs'    => array('czech', 'Czech', '&#268;esky'),
  'da'    => array('danish', 'Danish', 'Dansk'),
  'nl'    => array('dutch', 'Dutch', 'Nederlands'),
  'en'    => array('english', 'English', 'English'),
  'fi'    => array('finnish', 'Finnish', 'Suomi'),
  'fr'    => array('french', 'French', 'Fran&ccedil;ais'),
  'de'    => array('german', 'German', 'Deutsch'),
  'he-IL' => array('hebrew', 'Hebrew', '&#1506;&#1489;&#1512;&#1497;&#1514;'),
  'hin'   => array('hindi', 'Hindi', '&#2361;&#2367;&#2306;&#2342;&#2368;'),
  'hu'    => array('hungarian', 'Hungarian', 'Magyar'),
  'id'    => array('indonesian', 'Indonesian', 'Bahasa Indonesia'),
  'it'    => array('italian', 'Italian', 'Italiano'),
  'ja'    => array('japanese', 'Japanese', '&#26085;&#26412;&#35486;'),
  'ko'    => array('korean', 'Korean', '&#54620;&#44397;&#50612;'),
  'mk'    => array('macedonian', 'Macedonian', '&#1052;&#1072;&#1082;&#1077;&#1076;&#1086;&#1085;&#1089;&#1082;&#1080;'),
  'mr'    => array('marathi', 'Marathi', '&#2350;&#2352;&#2366;&#2336;&#2368;'),
  'no'    => array('norwegian', 'Norwegian', 'Norsk'),
  'pl'    => array('polish', 'Polish', 'Polski'),
  'pt'    => array('portuguese', 'Portuguese', 'Portugu&ecirc;s'),
  'pt-BR' => array('portuguese-br', 'Portuguese (Brazil)', 'Portugu&ecirc;s'),
  'ru'    => array('russian', 'Russian', '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;'),
  'sk'    => array('slovak', 'Slovak', 'Sloven&#269;ina'),
  'sl'    => array('slovenian', 'Slovenian', 'Sloven&#353;&#269;ina'),
  'es'    => array('spanish', 'Spanish', 'Espa&ntilde;ol'),
  'sv'    => array('swedish', 'Swedish', 'Svenska'),
  'tr'    => array('turkish', 'Turkish', 'T&uuml;rk&ccedil;e'),
  'uz'    => array('uzbek', 'Uzbek', 'O&euml;zbekcha'),
);
